pub struct Config {
pub vault_path: PathBuf,
pub rpc: HashMap<String, String>,
pub plugins: HashMap<String, Value>,
pub backup: Option<BackupConfig>,
}Expand description
Application configuration.
Fields
vault_path: PathBufrpc: HashMap<String, String>plugins: HashMap<String, Value>backup: Option<BackupConfig>Implementations
Sourceimpl Config
impl Config
Sourcepub fn default_rpc() -> HashMap<String, String>
pub fn default_rpc() -> HashMap<String, String>
Returns the built-in default RPC endpoints for well-known chains.
Sourceimpl Config
impl Config
Sourcepub fn load(path: &Path) -> Result<Self, OwsError>
pub fn load(path: &Path) -> Result<Self, OwsError>
Load config from a file path, or return defaults if file doesn’t exist.
Sourcepub fn load_or_default() -> Self
pub fn load_or_default() -> Self
Load ~/.ows/config.json, merging user overrides on top of defaults.
If the file doesn’t exist, returns the built-in defaults.
Sourcepub fn load_or_default_from(path: &Path) -> Self
pub fn load_or_default_from(path: &Path) -> Self
Load config from a specific path, merging user overrides on top of defaults.